/*****************************************************************************
*
*   Analog Devices, Inc.
*   ADSP-BF537 EZ-Kit Lite
*   Networked Audio Client
*
******************************************************************************
*
*   File        :   audio.h
*
*   Description :   This file contains header information for the audio
*                   application thread.
*
******************************************************************************
*   Revision History
******************************************************************************
*   date        rev     by      description
*-----------------------------------------------------------------------------
*   02.27.07    01.02h  KCK     Original release.
*****************************************************************************/

#ifndef _audio_H_
#define _audio_H_

#include "VDK.h"
#include <services/services.h>      // system service includes

#ifdef __ECC__	/* for C/C++ access */
#ifdef __cplusplus
extern "C" void audio_InitFunction(void**, VDK::Thread::ThreadCreationBlock *);
#else
extern "C" void audio_InitFunction(void**, VDK_ThreadCreationBlock *);
#endif
extern "C" void audio_DestroyFunction(void**);
extern "C" int  audio_ErrorFunction(void**);
extern "C" void audio_RunFunction(void**);
#endif /* __ECC__ */

#ifdef __cplusplus
#include <new>

class audio_Wrapper : public VDK::Thread
{
public:
    audio_Wrapper(VDK::ThreadCreationBlock &t)
        : VDK::Thread(t)
    { audio_InitFunction(&m_DataPtr, &t); }

    ~audio_Wrapper()
    { audio_DestroyFunction(&m_DataPtr); }

    int ErrorHandler()
    { 
      return audio_ErrorFunction(&m_DataPtr);
     }

    void Run()
    { audio_RunFunction(&m_DataPtr); }

    static VDK::Thread* Create(VDK::Thread::ThreadCreationBlock &t)
    { return new (t) audio_Wrapper(t); }
};

#endif /* __cplusplus */

extern int audioSocketID;

extern volatile u32 sportTCLKDIVAdjust;
extern volatile u32 sportTCLKDIVFast;
extern volatile u32 sportTCLKDIVSlow;
extern volatile u32 sportTCLKDIVDefault;


// function prototypes
void AudioOutputStart(void);
void AudioOutputInit(void);


// SPORT word lengths
#define SLEN_8  0x0007
#define SLEN_16 0x000F
#define SLEN_24 0x0017
#define SLEN_32 0x001f


// buffer definitions
#define AUDIO_RECV_BUFFER_LEN   1024
#define AUDIO_ELEMENT_COUNT     512
#define AUDIO_ELEMENT_WIDTH     2
#define AUDIO_BUFFER_LEN        (AUDIO_ELEMENT_COUNT * AUDIO_ELEMENT_WIDTH) // max number of characters per buffer

#define AUDIO_BUFFER_COUNT      8                   // number of buffers
#define AUDIO_BUFFER_MID        (AUDIO_BUFFER_COUNT >> 1)   // number of buffers / 2

// buffer flow control values
// These are based on a system clock value of 120 MHz.  We have to use an oddball I2S word length (25) in order
// to get 48k audio.
#define AUDIO_BUFFER_HI_THR     (AUDIO_BUFFER_COUNT - 2)
#define AUDIO_BUFFER_LO_THR     1

#define AUDIO_TCLKDIV_DEFAULT   24
#define AUDIO_TCLKDIV_FAST      23
#define AUDIO_TCLKDIV_SLOW      25
#define AUDIO_TFSDIV_DEFAULT    24
#define AUDIO_TCLKDIV_ADJ_PER   1 // adjustment period in mS

#endif /* _audio_H_ */


