/*****************************************************************************
*
*   Analog Devices, Inc.
*   ADSP-BF537 EZ-Kit Lite
*   Networked Audio Client
*
******************************************************************************
*
*   File        :   boot.h
*
*   Description :   This file contains boot thread header information.
*
******************************************************************************
*   Revision History
******************************************************************************
*   date        rev     by      description
*-----------------------------------------------------------------------------
*   02.27.07    01.02h  KCK     Original release.
*****************************************************************************/

#ifndef _boot_H_
#define _boot_H_

#include "VDK.h"
#include <services/services.h>      // system service includes
#include <drivers/adi_dev.h>        // device manager includes

extern  ADI_DEV_MANAGER_HANDLE  devManagerHandle;   // handle to the Device Manager
extern  ADI_DMA_MANAGER_HANDLE  dmaManagerHandle;   // handle to the DMA Manager
extern  ADI_DCB_HANDLE          dcbManagerHandle;   // handle to the Deferred Callback Manager

#ifdef __ECC__	/* for C/C++ access */
#ifdef __cplusplus
extern "C" void boot_InitFunction(void**, VDK::Thread::ThreadCreationBlock *);
#else
extern "C" void boot_InitFunction(void**, VDK_ThreadCreationBlock *);
#endif
extern "C" void boot_DestroyFunction(void**);
extern "C" int  boot_ErrorFunction(void**);
extern "C" void boot_RunFunction(void**);
#endif /* __ECC__ */

#ifdef __cplusplus
#include <new>

class boot_Wrapper : public VDK::Thread
{
public:
    boot_Wrapper(VDK::ThreadCreationBlock &t)
        : VDK::Thread(t)
    { boot_InitFunction(&m_DataPtr, &t); }

    ~boot_Wrapper()
    { boot_DestroyFunction(&m_DataPtr); }

    int ErrorHandler()
    { 
      return boot_ErrorFunction(&m_DataPtr);
     }

    void Run()
    { boot_RunFunction(&m_DataPtr); }

    static VDK::Thread* Create(VDK::Thread::ThreadCreationBlock &t)
    { return new (t) boot_Wrapper(t); }
};

#endif /* __cplusplus */
#endif /* _boot_H_ */

/* ========================================================================== */
