/*****************************************************************************
*
*   Analog Devices, Inc.
*   ADSP-BF537 EZ-Kit Lite
*   Networked Audio Client
*
******************************************************************************
*
*   File        :   keepalive.c
*
*   Description :   This file contains the keep alive functions.  These send
*                   keep alive messages back to the server at a periodic
*                   interval.
*
******************************************************************************
*   Revision History
******************************************************************************
*   date        rev     by      description
*-----------------------------------------------------------------------------
*   02.27.07    01.02h  KCK     Original release.
*****************************************************************************/
#include <lwip/sockets.h>
#include <lwip/inet.h>
#include <cdefBF537.h>

#include "system.h"
#include "keepalive.h"
#include "audio.h"

static char keepAliveMessage = 'a';


void
keepalive_RunFunction(void **inPtr)
    {
    int result;

    while (1)
        {
        // wait for keep alive interval to expire
        VDK_PendSemaphore(kLinkKeepAlive, 0);

        *pPORTFIO_TOGGLE = 0x0080;  // toggle LED 2


        // send packet over the network
        result = send(audioSocketID, &keepAliveMessage, 1, 0);
        }
    }

int
keepalive_ErrorFunction(void **inPtr)
    {
    VDK_DestroyThread(VDK_GetThreadID(), false);
    return 0;
    }

void
keepalive_InitFunction(void **inPtr, VDK_ThreadCreationBlock *pTCB)
    {
    }

void
keepalive_DestroyFunction(void **inPtr)
    {
    }

