/*****************************************************************************
*
*   Analog Devices, Inc.
*   ADSP-BF537 EZ-Kit Lite
*   Networked Audio Server
*
******************************************************************************
*
*   File        :   audio.h
*
*   Description :   This file contains header information for the main
*                   audio thread.
*
******************************************************************************
*   Revision History
******************************************************************************
*   date        rev     by      description
*-----------------------------------------------------------------------------
*   02.27.07    01.02h  KCK     Original release.
*****************************************************************************/
#ifndef _audio_H_
#define _audio_H_

#include "VDK.h"
#include <services/services.h>      // system service includes
#include <drivers/adi_dev.h>        // device manager includes
#include "queue.h"

#define AUDIO_BUFFER_COUNT      (8)         // number of buffers 
#define AUDIO_ELEMENT_COUNT     (512)       // number of samples in each buffer
#define AUDIO_ELEMENT_WIDTH     (2)         // number of bytes per sample
#define AUDIO_BUFFER_LEN        (AUDIO_ELEMENT_COUNT * AUDIO_ELEMENT_WIDTH)
#define AUDIO_PACKET_MAX        (40)

extern ADI_DEV_1D_BUFFER   audioBuffer[AUDIO_BUFFER_COUNT];                // the buffer descriptors
extern u8                  audioData[AUDIO_BUFFER_COUNT][AUDIO_BUFFER_LEN];// the actual data buffers
extern u32                 audioPacketCount;

extern queue_t audioQueue;
extern queueEntry_t audioQueueEntry[AUDIO_BUFFER_COUNT];


extern ADI_DEV_DEVICE_HANDLE   audioInHandle;   // handle to the audio input driver


extern int     audioSocketID;
extern struct  sockaddr_in clientAudioSocketAddress;
extern struct  sockaddr_in serverAudioSocketAddress;


#ifdef __ECC__	/* for C/C++ access */
#ifdef __cplusplus
extern "C" void audio_InitFunction(void**, VDK::Thread::ThreadCreationBlock *);
#else
extern "C" void audio_InitFunction(void**, VDK_ThreadCreationBlock *);
#endif
extern "C" void audio_DestroyFunction(void**);
extern "C" int  audio_ErrorFunction(void**);
extern "C" void audio_RunFunction(void**);
#endif /* __ECC__ */

#ifdef __cplusplus
#include <new>

class audio_Wrapper : public VDK::Thread
{
public:
    audio_Wrapper(VDK::ThreadCreationBlock &t)
        : VDK::Thread(t)
    { audio_InitFunction(&m_DataPtr, &t); }

    ~audio_Wrapper()
    { audio_DestroyFunction(&m_DataPtr); }

    int ErrorHandler()
    { 
      return audio_ErrorFunction(&m_DataPtr);
     }

    void Run()
    { audio_RunFunction(&m_DataPtr); }

    static VDK::Thread* Create(VDK::Thread::ThreadCreationBlock &t)
    { return new (t) audio_Wrapper(t); }
};

#endif /* __cplusplus */


#endif /* _audio_H_ */

/* ========================================================================== */
